<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class auth_facebook_admin extends MX_Controller
{

    public function manage()
    {
        $this->load->library('ciext/configurator');
        $conf = new configurator('auth_facebook');
        $conf->add_input('app_id');
        $conf->add_input('app_secret');
        $conf->add_input('redirect_link');

        $conf->display_as('redirect_link', $this->lang->line('Redirect link'));
        $conf->display_as('app_id', $this->lang->line('App ID'));
        $conf->display_as('app_secret', $this->lang->line('App secret'));

        return array('content' => $this->getExplains() . $conf->render(), 'title' => $this->lang->line('Auth by facebook'));
    }

    protected function getExplains()
    {
        return '<div style="width:100%;float:left;margin-bottom:15px;padding: 10px;border: 1px solid #333;">' . $this->lang->line('Инструкция!<br>Перейдите по <a href="https://developers.facebook.com/apps" target="_blank">ССЫЛКЕ</a> и получите все необходимые данные для работы с facebook API. Для этого кликните по "Добавить новое приложение" и далее заполните запрашиваемые данные. После того как получите "App ID" и "App secret" не забудьте включить "Сделать приложение «Auth» доступным для всех" в меню "Проверка приложения", так как без этого авторизация работать не будет.') . '</div>';
    }

}
